# lambdata-khislatz

## Installation

TODO 

## Usage 

TODO

'''py
from my_lambdata.my_mod import enlarge #this works

x = 11 
print(enlarge(x)) #importing only enlarge function
#if we use from my_mod import enlarge without "if __name__ == "__main__":"
# then the entire file my_mod will be executed 
'''